package com.bonus.material.lease.service;

import java.util.List;
import com.bonus.material.lease.domain.LeaseUserBook;

/**
 * 预约车Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ILeaseUserBookService {
    /**
     * 查询预约车
     * 
     * @param id 预约车主键
     * @return 预约车
     */
    public LeaseUserBook selectLeaseUserBookById(Long id);

    /**
     * 查询预约车列表
     * 
     * @param leaseUserBook 预约车
     * @return 预约车集合
     */
    public List<LeaseUserBook> selectLeaseUserBookList(LeaseUserBook leaseUserBook);

    /**
     * 新增预约车
     * 
     * @param leaseUserBook 预约车
     * @return 结果
     */
    public int insertLeaseUserBook(LeaseUserBook leaseUserBook);

    /**
     * 修改预约车
     * 
     * @param leaseUserBook 预约车
     * @return 结果
     */
    public int updateLeaseUserBook(LeaseUserBook leaseUserBook);

    /**
     * 批量删除预约车
     * 
     * @param ids 需要删除的预约车主键集合
     * @return 结果
     */
    public int deleteLeaseUserBookByIds(Long[] ids);

    /**
     * 删除预约车信息
     * 
     * @param id 预约车主键
     * @return 结果
     */
    public int deleteLeaseUserBookById(Long id);
}
