package com.bonus.material.lease.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.lease.domain.LeaseUserBook;
import com.bonus.material.lease.service.ILeaseUserBookService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 预约车Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "预约车接口")
@RestController
@RequestMapping("/lease_user_book")
public class LeaseUserBookController extends BaseController {
    @Autowired
    private ILeaseUserBookService leaseUserBookService;

    /**
     * 查询预约车列表
     */
    @ApiOperation(value = "查询预约车列表")
    @RequiresPermissions("lease:book:list")
    @GetMapping("/list")
    public TableDataInfo list(LeaseUserBook leaseUserBook) {
        startPage();
        List<LeaseUserBook> list = leaseUserBookService.selectLeaseUserBookList(leaseUserBook);
        return getDataTable(list);
    }

    /**
     * 导出预约车列表
     */
    @ApiOperation(value = "导出预约车列表")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:book:export")
    @SysLog(title = "预约车", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出预约车")
    @PostMapping("/export")
    public void export(HttpServletResponse response, LeaseUserBook leaseUserBook) {
        List<LeaseUserBook> list = leaseUserBookService.selectLeaseUserBookList(leaseUserBook);
        ExcelUtil<LeaseUserBook> util = new ExcelUtil<LeaseUserBook>(LeaseUserBook.class);
        util.exportExcel(response, list, "预约车数据");
    }

    /**
     * 获取预约车详细信息
     */
    @ApiOperation(value = "获取预约车详细信息")
    @RequiresPermissions("lease:book:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(leaseUserBookService.selectLeaseUserBookById(id));
    }

    /**
     * 新增预约车
     */
    @ApiOperation(value = "新增预约车")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:book:add")
    @SysLog(title = "预约车", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增预约车")
    @PostMapping
    public AjaxResult add(@RequestBody LeaseUserBook leaseUserBook) {
        try {
            return toAjax(leaseUserBookService.insertLeaseUserBook(leaseUserBook));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改预约车
     */
    @ApiOperation(value = "修改预约车")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:book:edit")
    @SysLog(title = "预约车", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改预约车")
    @PutMapping
    public AjaxResult edit(@RequestBody LeaseUserBook leaseUserBook) {
        try {
            return toAjax(leaseUserBookService.updateLeaseUserBook(leaseUserBook));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除预约车
     */
    @ApiOperation(value = "删除预约车")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:book:remove")
    @SysLog(title = "预约车", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除预约车")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(leaseUserBookService.deleteLeaseUserBookByIds(ids));
    }
}
